@@ -1,5 +1,4 @@
 #include <linux/delay.h>
-
 #include "ddk750_defs.h"
 #include "ddk750_hardware.h"
 #include "ddk750_power.h"
@@ -221,7 +220,7 @@ static void swI2CAck(unsigned char ack)
 /*
  *  This function sends the start command to the slave device
  */
-void swI2CStart(void)
+static void swI2CStart(void)
 {
     /* Start I2C */
     swI2CSDA(1);
@@ -232,7 +231,7 @@ void swI2CStart(void)
 /*
  *  This function sends the stop command to the slave device
  */
-void swI2CStop(void)
+static void swI2CStop(void)
 {
     /* Stop the I2C */
     swI2CSCL(1);
@@ -250,7 +249,7 @@ void swI2CStop(void)
  *       0   - Success
  *      -1   - Fail to write byte
  */
-long swI2CWriteByte(unsigned char data) 
+static long swI2CWriteByte(unsigned char data) 
 {
     unsigned char value = data;
     int i;
@@ -313,7 +312,7 @@ long swI2CWriteByte(unsigned char data)
  *  Return Value:
  *      One byte data read from the Slave device
  */
-unsigned char swI2CReadByte(unsigned char ack)
+static unsigned char swI2CReadByte(unsigned char ack)
 {
     int i;
     unsigned char data = 0;
@@ -541,7 +540,7 @@ long swI2CWriteReg(
     return returnValue;
 }
 
-long adapterI2CInit(
+static long adapterI2CInit(
     unsigned char i2cClkGPIO, 
     unsigned char i2cDataGPIO
 )
@@ -802,3 +801,22 @@ long ddk750_AdaptSWI2CInit(struct smi_connector *smi_connector)
     return 0;
 }
 
+/* After closing HW I2C, give a SCL clk by SW to avoid the deadlock */
+long ddk750_AdapSWI2CCleanBus(
+    struct smi_connector *connector)
+{
+    unsigned char i2cClkGPIO = connector->i2c_scl;
+    unsigned char i2cDataGPIO = connector->i2c_sda;
+
+    if (adapterI2CInit(i2cClkGPIO, i2cDataGPIO))
+        return (-1);
+
+    udelay(20);
+    swI2CSCL(0);
+    udelay(20);
+    swI2CSCL(1);
+    udelay(20);
+
+    return 0;
+}
+
