@@ -3,7 +3,6 @@
 #include "ddk768_hwi2c.h"
 #include "ddk768_swi2c.h"
 #include "ddk768_edid.h"
-
 #include "ddkdebug.h"
 
 
@@ -119,7 +118,7 @@ static void printVdif(
  *  Output:
  *      0 get header success; -1 fail.
  */
-unsigned char edidGetHeader(
+__attribute__((unused)) static unsigned char edidGetHeader(
     unsigned char *pEDIDBuffer
 )
 {
@@ -980,8 +979,10 @@ unsigned char ddk768_edidGetExtension(
     return 0;
 }
 
-#if 0
+
 #define EDID_TOTAL_RETRY_COUNTER            1
+
+#if 0
 /*
  *  ddk768_edidReadMonitor
  *      This function reads the EDID structure from the attached monitor
@@ -1074,6 +1075,7 @@ long ddk768_edidReadMonitorEx(
 
     return edidSize;
 }
+#endif
 
 /*
  *  This function is same as editReadMonitorEx(), but using HW I2C.
@@ -1188,7 +1190,7 @@ long ddk768_edidReadMonitorExHwI2C(
     return edidSize;
 }
 
-
+#if 0
 
 /*
  *  ddk768_edidReadMonitor
@@ -1292,6 +1294,8 @@ long ddk768_edidHeaderReadMonitorEx(
     return 0;
 }
 
+#endif
+
 long ddk768_edidHeaderReadMonitorExHwI2C(
     unsigned char i2cNumber
 )
@@ -1317,7 +1321,7 @@ long ddk768_edidHeaderReadMonitorExHwI2C(
     }
 
 	/* Finish using HW I2C, we can close the device. */
-    ddk768_hwI2CClose(i2cNumber);
+    //ddk768_hwI2CClose(i2cNumber);
 
     /*
      *  The monitor might not be DDC2B compliance. Therefore, need to use DDC1 protocol,
@@ -1330,13 +1334,13 @@ long ddk768_edidHeaderReadMonitorExHwI2C(
          * only an acknowledge flag, which could be high or low. However, SCL line
          * is not used. Instead the data is clock-in using vertical sync.
          */
-        return (-1);
+        return 0;
     }
 
-    return 0;
+    return 1;
 }
 
-#endif
+
 
 /*
  *  ddk768_edidGetEstablishedTiming
