@@ -2,10 +2,9 @@
 #define _EDID_H_
 
 #include "ddk768_display.h"
+#include "../hw_com.h"
 #include "vdif.h"
 
-#define EDID_DEVICE_I2C_ADDRESS             0xA0
-#define TOTAL_EDID_REGISTERS                128
 
 /* Set the alignment to 1-bit aligned. Otherwise, it can't get the EDID correctly. */
 #pragma pack(1)
@@ -13,291 +12,6 @@
 #define TOTAL_EDID_REGISTERS_128                128
 #define TOTAL_EDID_REGISTERS_256                256
 #define EDID_EXTEND_BLOCK         126
-#define READ_EDID_CONTINUOUS
-
-
-/* Standard Timing Structure */
-typedef struct _standard_timing_t
-{
-    unsigned char horzActive;       /* (Horizontal active pixels / 8 ) - 31 */
-    struct
-    {
-        unsigned char refreshRate:6;    /* Refresh Rate (Hz) - 60; Range 60 --> 123 */
-        unsigned char aspectRatio:2;    /* Aspect Ratio:
-                                            Bit 7   Bit 6   Operation
-                                              0       0        1:1      (prior Version 1.3)
-                                              0       0       16:10     (Version 1.3)
-                                              0       1        4:3
-                                              1       0        5:4
-                                              1       1       16:9
-                                         */
-    } stdTimingInfo;
-} standard_timing_t;
-
-/* Detailed Timing Description Structure */
-typedef struct _detailed_timing_t
-{
-    unsigned short pixelClock;
-    unsigned char horzActive;
-    unsigned char horzBlanking;
-    struct 
-    {
-        unsigned char horzBlankingMSB:4;
-        unsigned char horzActiveMSB:4;
-    } horzActiveBlanking;
-    unsigned char vertActive;
-    unsigned char vertBlanking;
-    struct 
-    {
-        unsigned char vertBlankingMSB:4;
-        unsigned char vertActiveMSB:4;
-    } vertActiveBlanking;
-    unsigned char horzSyncOffset;
-    unsigned char horzSyncPulseWidth;
-    struct
-    {
-        unsigned char syncWidth:4;
-        unsigned char syncOffset:4;
-    } verticalSyncInfo;
-    struct
-    {
-        unsigned char vertSyncWidth:2;
-        unsigned char vertSyncOffset:2;
-        unsigned char horzSyncWidth:2;
-        unsigned char horzSyncOffset:2;
-    } syncAuxInfo;
-    unsigned char horzImageSize;
-    unsigned char vertImageSize;
-    struct
-    {
-        unsigned char vertImageSizeMSB:4;
-        unsigned char horzImageSizeMSB:4;
-    } horzVertImageSize;
-    unsigned char horzBorder;
-    unsigned char vertBorder;
-    struct
-    {
-        unsigned char interleaved:1;
-        unsigned char horzSyncFlag:1;
-        unsigned char vertSyncFlag:1;
-        unsigned char connectionType:2;
-        unsigned char stereo:2;
-        unsigned char interlaced:1;
-    } flags;
-} detailed_timing_t;
-
-typedef struct _color_point_t
-{
-    unsigned char whitePointIndex;
-    struct
-    {
-        unsigned char whiteYLowBits:2;
-        unsigned char whiteXLowBits:2;
-        unsigned char reserved:4;
-    } whiteLowBits;
-    unsigned char whiteX;
-    unsigned char whiteY;
-    unsigned char gamma;
-} color_point_t;
-
-typedef struct _monitor_desc_t
-{
-    unsigned short flag1;               /* Flag = 0000h when block used as descriptor */
-    unsigned char flag2;                /* Flag = 00h when block used as descriptor */
-    unsigned char dataTypeTag;          /* Data type tag:
-                                                FFh: Monitor Serial Number - Stored as ASCII, 
-                                                     code page #437, <= 13bytes
-                                                FEh: ASCII String - Stored as ASCII, code 
-                                                     page #437, <= 13 bytes
-                                                FDh: Monitor range limits, binary coded
-                                                FCh: Monitor name, stored as ASCII, code page #437
-                                                FBh: Descriptor contains additional color point data
-                                                FAh: Descriptor contains additional Standard Timing
-                                                     Identifications
-                                                F9h-11h: Currently undefined
-                                                10h: Dummy descriptor, used to indicate 
-                                                     that the descriptor space is unused
-                                                0Fh-00h: Descriptor defined by manufacturer.
-                                         */
-    unsigned char flag3;                /* Flag = 00h when block used as descriptor */
-    union
-    {
-        unsigned char serialNo[13];
-        unsigned char dataString[13];
-        struct
-        {
-            unsigned char minVertRate;
-            unsigned char maxVertRate;
-            unsigned char minHorzFrequency;
-            unsigned char maxHorzFrequency;
-            unsigned char maxPixelClock;        /* Binary coded clock rate in MHz / 10 
-                                                   Max Pixel Clock those are not a multiple of 10MHz
-                                                   is rounded up to a multiple of 10MHz
-                                                 */
-            unsigned char secondaryTimingFlag;  /* 00h = No secondary timing formula supported
-                                                   (Support for default GTF indicated in feature byte)
-                                                   02h = Channel1 GTF curve supported
-                                                   All other = Reserved for future timing formula
-                                                               definitions.
-                                                 */
-            union
-            {
-                unsigned char constantStr[7];
-                struct
-                {
-                    unsigned char reserved;
-                    unsigned char startFrequency;
-                    unsigned char cParam;
-                    unsigned short mParam;
-                    unsigned char kParam;
-                    unsigned char jParam;
-                } cmkjParam;
-            } secondaryTimingInfo;
-        } monitorRange;
-        
-        unsigned char monitorName[13];
-        struct
-        {
-            color_point_t white[2];
-            unsigned char reserved[3];          /* Set to (0Ah, 20h, 20h)*/
-        } colorPoint;
-        
-        struct
-        {
-            standard_timing_t stdTiming[6];
-            unsigned char reserved;             /* Set to 0Ah */
-        } stdTimingExt;
-        
-        unsigned char manufactureSpecifics[13];
-    } descriptor; 
-}
-monitor_desc_t;
-
-/* EDID Structuve Version 1. Within version 1 itself, there are 4 revisions mentioned
-   below: 
-    - EDID 1.0: The original 128-byte data format
-    - EDID 1.1: Added definitions for monitor descriptors as an alternate use of the space 
-                originally reserved for detailed timings, as well as definitions for 
-                previously unused fields.
-    - EDID 1.2: Added definitions to existing data fields.
-    - EDID 1.3: Added definitions for secondary GTF curve coefficients. This is the new
-                baseline for EDID data structures, which is recommended for all new monitor
-                designs.
- */
-typedef struct _edid_version_1_t
-{
-    /* Header (8 bytes) */
-    unsigned char header[8];            /* Header */
-    
-    /* Vendor / Product ID (10 bytes) */
-    unsigned short manufacturerID;      /* Manufacture Identification */
-    unsigned short productCode;         /* Product code Identification */ 
-    unsigned long serialNumber;         /* Serial Number */
-    unsigned char weekOfManufacture;    /* Week of Manufacture */
-    unsigned char yearOfManufacture;    /* Year of Manufacture */
-    
-    /* EDID Structure version / revision (2 bytes) */
-    unsigned char version;              /* EDID Structure Version no. */
-    unsigned char revision;             /* Revision Version no. */
-    
-    /* Basic Display Parameters / Features (5 bytes) */
-    union
-    {
-        struct
-        {
-            unsigned char vsyncSerration:1;
-            unsigned char syncOnGreenSupport:1;
-            unsigned char compositeSyncSupport:1;
-            unsigned char separateSyncSupport:1;
-            unsigned char blank2Black:1;
-            unsigned char signalLevelStd:2;
-            unsigned char inputSignal:1;    /* Input Signal: Analog = 0, Digital = 1 */
-        } analogSignal;
-        struct
-        {
-            unsigned char dfp1Support:1;
-            unsigned char reserved:6;
-            unsigned char inputSignal:1;    /* Input Signal: Analog = 0, Digital = 1 */
-        } digitalSignal;
-    } videoInputDefinition;             /* Video Input Definition */
-
-    unsigned char maxHorzImageSize;     /* Maximum Horizontal Image Size */
-    unsigned char maxVertImageSize;     /* Maximum Vertical Image Size */
-    unsigned char displayTransferChar;  /* Display Transfer Characteristic (Gamma) */
-    struct
-    {
-        unsigned char defaultGTFSupport:1;  /* Support timings based on the GTF standard using
-                                               default GTF parameters 
-                                             */ 
-        unsigned char preferredTiming:1;    /* If set, the display's preferred timing mode is
-                                               indicated in the first detailed timing block.
-                                             */
-        unsigned char sRGBSupport:1;        /* If set, the display uses the sRGB standard
-                                               default color space as its primary color space
-                                             */
-        unsigned char displayType:2;        /* Display Type:
-                                                    00  - Monochrome / Grayscale display
-                                                    01  - RGB Color Display
-                                                    10  - Non-RGB multicolor display, e.g. R/G/Y
-                                                    11  - Undefined
-                                             */
-        unsigned char lowPowerSupport:1;    /* If set, the display consumes much less power when
-                                               it receives a timing signal outside its active
-                                               operating range. It will revert to normal if the
-                                               timing returns to the normal operating range.
-                                             */
-        unsigned char suspendSupport:1;     /* Support Suspend as defined in VESA DPMS spec. */
-        unsigned char standbySupport:1;     /* Support Standby as defined in VESA DPMS spec. */
-    } featureSupport;                   /* Feature Support */
-    
-    /* Color Characteristics (10 bytes) */
-    struct
-    {
-        unsigned char greenYLowBits:2;
-        unsigned char greenXLowBits:2;
-        unsigned char redYLowBits:2;
-        unsigned char redXLowBits:2;
-    } redGreenLowBits;                  /* Red/Green Low Bits */
-    struct
-    {
-        unsigned char whiteYLowBits:2;
-        unsigned char whiteXLowBits:2;
-        unsigned char blueYLowBits:2;
-        unsigned char blueXLowBits:2;
-    } blueWhiteLowBits;                 /* Blue/White Low Bits */
-    unsigned char redX;                 /* Red-x bits 9-2 */
-    unsigned char redY;                 /* Red-y bits 9-2 */
-    unsigned char greenX;               /* Green-x bits 9-2 */
-    unsigned char greenY;               /* Green-y bits 9-2 */
-    unsigned char blueX;                /* Blue-x bits 9-2 */
-    unsigned char blueY;                /* Blue-y bits 9-2 */
-    unsigned char whiteX;               /* White-x bits 9-2 */
-    unsigned char whiteY;               /* White-y bits 9-2 */
-    
-    /* Established Timings (3 bytes) */
-    unsigned char estTiming[3];         /* Established Timings */
-    
-    /* Standard Timing Identification (16 bytes) */
-    standard_timing_t stdTiming[8];     /* Standard Timings Identification */
-
-    /* Detailed Timing Descriptions (72 bytes) */
-    union
-    {
-        detailed_timing_t detailTiming[4];  /* Detailed Timing Descriptor */
-        monitor_desc_t monitorDesc[4];  /* Monitor descriptor */
-    } miscInformation;
-    
-    /* Extension Flag (1 byte) */
-    unsigned char extFlag;              /* Number of (optional) 1280byte EDID
-                                           extension blocks to follow. 
-                                         */
-                                         
-    /* Checksum (1 byte) */
-    unsigned char checksum;             /* The 1-byte sum of all 128 bytes in 
-                                           this EDID block shall equal zero. 
-                                         */
-}
-edid_version_1_t;
 
 #if 0   /* Temporary on hold. To be completed later. */
 
@@ -723,6 +437,30 @@ long ddk768_edidGetWhitePoint(
     unsigned short *pWhiteGamma
 );
 
+/*
+ *  This function is same as editReadMonitorEx(), but using HW I2C.
+ *
+ *  Input:
+ *      pEDIDBuffer - Buffer that contains the EDID structure of the monitor
+ *      bufferSize  - The EDID Buffer size index (usually 128-bytes)
+ *      edidExtNo   - Extension Index of the EDID Structure to be read
+ *      i2cNumber   - 0 = I2C0 and 1 = I2C1
+ *
+ *  Output:
+ *      0   - Fail
+ *     edidSize   - Success and return the edid's size.
+ */
+long ddk768_edidReadMonitorExHwI2C(
+    unsigned char *pEDIDBuffer,
+    unsigned long bufferSize,
+    unsigned char edidExtNo,
+    unsigned char i2cNumber
+);
+
+long ddk768_edidHeaderReadMonitorExHwI2C(
+    unsigned char i2cNumber
+);
+
 /*
  *  ddk768_edidGetExtension
  *      This function gets the number of (optional) EDID extension blocks to follow
