@@ -22,6 +22,7 @@
 #include <drm/drm_crtc_helper.h>
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 1, 0)
 #include <drm/drm_probe_helper.h>
+
 #endif
 
 
@@ -31,7 +32,7 @@
 #include "ddk768/ddk768_chip.h"
 #include "smi_dbg.h"
 
-
+#define MAX_COLOR_LUT_ENTRIES 256
 
 int smi_calc_hdmi_ctrl(int m_connector)
 {
@@ -72,9 +73,9 @@ static int smi_crtc_gamma_set(struct drm_crtc *crtc, u16 *r, u16 *g,
 		}
 	}
 	
-	dst_ctrl = (ctrl_index == SMI1_CTRL)?SMI1_CTRL:SMI0_CTRL;
+	dst_ctrl = (ctrl_index == CHANNEL1_CTRL)?CHANNEL1_CTRL:CHANNEL0_CTRL;
 
-	if(ctrl_index > SMI1_CTRL)
+	if(ctrl_index > CHANNEL1_CTRL)
 	{
 		dst_ctrl= smi_calc_hdmi_ctrl(sdev->m_connector);
 	}
@@ -89,7 +90,10 @@ static int smi_crtc_gamma_set(struct drm_crtc *crtc, u16 *r, u16 *g,
 
 
 	if (sdev->specId == SPC_SM768) {
-		hw768_setgamma(dst_ctrl, true , lvds_channel);
+		if(sdev->m_connector & USE_DVI)
+			hw768_setgamma(dst_ctrl, true , lvds_channel);
+		else
+			hw768_setgamma(dst_ctrl, true , 0);
 		hw768_load_lut(dst_ctrl, crtc->gamma_size, smi_crtc->lut_r, smi_crtc->lut_g, smi_crtc->lut_b);
 	
 	}else if(sdev->specId == SPC_SM750) {
@@ -128,6 +132,7 @@ static void smi_crtc_mode_set_nofb(struct drm_crtc *crtc)
 	mode = &crtc->state->adjusted_mode;
 	refresh_rate = drm_mode_vrefresh(mode);
 
+	
 	dbg_msg("***crtc addr:%p\n", crtc);
 
 	dbg_msg("encode->crtc:[%p, %p, %p] \n", sdev->smi_enc_tab[0]->crtc, sdev->smi_enc_tab[1]->crtc,
@@ -138,20 +143,20 @@ static void smi_crtc_mode_set_nofb(struct drm_crtc *crtc)
 	dbg_msg("wxh:%dx%d@%ldHz\n", mode->hdisplay, mode->vdisplay, refresh_rate);
 
 	if (sdev->specId == SPC_SM750) {
-			if(crtc == sdev->smi_enc_tab[0]->crtc)
+		if(crtc == sdev->smi_enc_tab[0]->crtc)
 		{
 			logicalMode.baseAddress = 0;
 			logicalMode.x = mode->hdisplay;
 			logicalMode.y = mode->vdisplay;
 			logicalMode.bpp = smi_bpp;
-			logicalMode.dispCtrl = SMI0_CTRL;
+			logicalMode.dispCtrl = CHANNEL0_CTRL;
 			logicalMode.hz = refresh_rate;
 			logicalMode.pitch = 0;
 
 			setMode(&logicalMode);
 
-			setDisplayControl(SMI0_CTRL, DISP_ON);           /* Turn on Primary Control */
-			setPath(SMI0_PATH, SMI0_CTRL, DISP_ON);     /* Turn on Panel Path and use Primary data */
+			setDisplayControl(CHANNEL0_CTRL, DISP_ON);           /* Turn on Primary Control */
+			setPath(SMI0_PATH, CHANNEL0_CTRL, DISP_ON);     /* Turn on Panel Path and use Primary data */
 			
 		}
 		if(crtc == sdev->smi_enc_tab[1]->crtc)
@@ -160,13 +165,13 @@ static void smi_crtc_mode_set_nofb(struct drm_crtc *crtc)
 			logicalMode.x = mode->hdisplay;
 			logicalMode.y = mode->vdisplay;
 			logicalMode.bpp = smi_bpp;
-			logicalMode.dispCtrl = SMI1_CTRL;
+			logicalMode.dispCtrl = CHANNEL1_CTRL;
 			logicalMode.hz = refresh_rate;
 			logicalMode.pitch = 0;
 			setMode(&logicalMode);
 
-			setDisplayControl(SMI1_CTRL, DISP_ON);         /* Turn on Secondary control */
-			setPath(SMI1_PATH, SMI1_CTRL, DISP_ON);     /* Turn on CRT Path and use Secondary data */
+			setDisplayControl(CHANNEL1_CTRL, DISP_ON);         /* Turn on Secondary control */
+			setPath(SMI1_PATH, CHANNEL1_CTRL, DISP_ON);     /* Turn on CRT Path and use Secondary data */
 			
 		}
 		
@@ -192,9 +197,9 @@ static void smi_crtc_mode_set_nofb(struct drm_crtc *crtc)
 			}
 		}
 
-		dst_ctrl = (ctrl_index == SMI1_CTRL)?SMI1_CTRL:SMI0_CTRL;
+		dst_ctrl = (ctrl_index == CHANNEL1_CTRL)?CHANNEL1_CTRL:CHANNEL0_CTRL;
 		
-		if(ctrl_index > SMI1_CTRL)
+		if(ctrl_index > CHANNEL1_CTRL)
 		{
 			dst_ctrl=smi_calc_hdmi_ctrl(sdev->m_connector);
 			dbg_msg("hdmi use channel %d\n",dst_ctrl);
@@ -209,7 +214,7 @@ static void smi_crtc_mode_set_nofb(struct drm_crtc *crtc)
 		logicalMode.pitch = 0;
 		logicalMode.dispCtrl = dst_ctrl;
 
-		switch (ctrl_index)
+		switch (ctrl_index) // 0:DVI, 1:VGA, 2:HDMI
 		{
 			case 0:
 				if (sdev->dvi_edid && drm_edid_header_is_valid((u8 *)sdev->dvi_edid) == 8)
@@ -283,7 +288,7 @@ static void smi_crtc_mode_set_nofb(struct drm_crtc *crtc)
 		else
 			hw768_SetPixelClockFormat(dst_ctrl,0);
 #endif
-		if((sdev->m_connector & USE_HDMI)&&(ctrl_index > SMI1_CTRL))
+		if((sdev->m_connector & USE_HDMI)&&(ctrl_index > CHANNEL1_CTRL))
 		{
 			int ret = 0;
 			printk("Starting init SM768 HDMI! Use Channel [%d]\n", dst_ctrl);
@@ -296,15 +301,17 @@ static void smi_crtc_mode_set_nofb(struct drm_crtc *crtc)
 			}
 		}
 		
-
-		if(lvds_channel == 1){
-			printk("Use Single Channel LVDS\n");
-			hw768_enable_lvds(1);
-		}
-		else if(lvds_channel == 2){
-			printk("Use Dual Channel LVDS\n");
-			hw768_enable_lvds(2);
-			EnableDoublePixel(0);
+		if((sdev->m_connector & USE_DVI) && dst_ctrl == 0){  //LVDS and TTL always use CH0
+			if(lvds_channel == 1){
+				printk("Use Single Channel LVDS\n");
+				hw768_enable_lvds(1);
+				DisableDoublePixel(0);
+			}
+			else if(lvds_channel == 2){
+				printk("Use Dual Channel LVDS\n");
+				hw768_enable_lvds(2);
+				EnableDoublePixel(0);
+			}
 		}		
 
 	
@@ -330,7 +337,6 @@ static void smi_crtc_atomic_flush(struct drm_crtc *crtc,
 	struct drm_crtc_state *old_state)
 #endif
 {
-	
 	unsigned long flags;
 	ENTER();
 	spin_lock_irqsave(&crtc->dev->event_lock, flags);
@@ -443,19 +449,19 @@ static struct smi_crtc *smi_crtc_init(struct drm_device *dev, int crtc_id)
 		}
 	}
 	smi_crtc->CursorOffset = 0;
-
+	
 	r = drm_crtc_init_with_planes(dev, &smi_crtc->base, primary, cursor, &smi_crtc_funcs, NULL);
-
 	if (r) {
 		goto clean_cursor;
 	}
 
-	drm_mode_crtc_set_gamma_size(&smi_crtc->base, 256);
-	
 	for (i = 0; i < smi_crtc->base.gamma_size; i++)
 	{
 		smi_crtc->lut_r[i] = smi_crtc->lut_g[i] = smi_crtc->lut_b[i] = i;
 	}
+	drm_crtc_enable_color_mgmt(&smi_crtc->base, 0, false, MAX_COLOR_LUT_ENTRIES);
+	drm_mode_crtc_set_gamma_size(&smi_crtc->base, MAX_COLOR_LUT_ENTRIES);
+	
 	drm_crtc_helper_add(&smi_crtc->base, &smi_crtc_helper_funcs);
 	return smi_crtc;
 
@@ -533,15 +539,15 @@ static void smi_encoder_dpms(struct drm_encoder *encoder, int mode)
 		else if(encoder->encoder_type  == DRM_MODE_ENCODER_TMDS)
 		{	
 			if (mode == DRM_MODE_DPMS_OFF)	
-				hw768_HDMI_Disable_Output();
+				HDMI_Disable_Output();
 			else
-				hw768_HDMI_Enable_Output();
+				HDMI_Enable_Output();
 			if(sdev->m_connector == USE_DVI_HDMI){
-				index = SMI1_CTRL;
+				index = CHANNEL1_CTRL;
 			 	dbg_msg("HDMI connector: index=%d\n",index);
 			}
 			else if(sdev->m_connector == USE_VGA_HDMI || sdev->m_connector == USE_HDMI){
-				index = SMI0_CTRL;
+				index = CHANNEL0_CTRL;
 			 	dbg_msg("HDMI connector: index=%d\n",index);
 			}else{
 				dbg_msg("HDMI connector not set dpms\n");
@@ -557,8 +563,10 @@ static void smi_encoder_dpms(struct drm_encoder *encoder, int mode)
 			ddk768_swPanelPowerSequence(index, 1, 4);
 		}
 		
-		if(lvds_channel == 2)
+		if(lvds_channel == 2 && (sdev->m_connector & USE_DVI) )
 			EnableDoublePixel(0);
+		else
+			DisableDoublePixel(0);
 
 	}
 	
@@ -577,7 +585,7 @@ static void smi_encoder_commit(struct drm_encoder *encoder)
 
 }
 
-void smi_encoder_destroy(struct drm_encoder *encoder)
+static void smi_encoder_destroy(struct drm_encoder *encoder)
 {
 	struct smi_encoder *smi_encoder = to_smi_encoder(encoder);
 	drm_encoder_cleanup(encoder);
@@ -633,13 +641,13 @@ static struct drm_encoder *smi_encoder_init(struct drm_device *dev, int index)
 }
 
 
-int smi_connector_get_modes(struct drm_connector *connector)
+static int smi_connector_get_modes(struct drm_connector *connector)
 {
 #ifdef USE_HDMICHIP
 	int ret = 0;
+	void *edid_buf = NULL;
 #endif
 	int count = 0;
-	void *edid_buf = NULL;
 	struct smi_device *sdev = connector->dev->dev_private;
 	struct smi_connector *smi_connector = to_smi_connector(connector);
 
@@ -661,7 +669,7 @@ int smi_connector_get_modes(struct drm_connector *connector)
 
 			edid_buf = sdev->si9022_edid;
 			if(ddk750_GetDDC_9022Access())
-				ret = ddk750_edidReadMonitorEx(SMI0_CTRL, edid_buf, 256, 0, 30, 31);
+				ret = ddk750_edidReadMonitorEx(CHANNEL0_CTRL, edid_buf, 256, 0, 30, 31);
 			ddk750_Release9022DDC();
 			if(ret){
               	drm_connector_update_edid_property(connector, sdev->si9022_edid);
@@ -678,16 +686,19 @@ int smi_connector_get_modes(struct drm_connector *connector)
 
 
 #else
-			edid_buf = drm_get_edid(connector, &smi_connector->adapter);
+		
 
-			if(edid_buf)
+		    sdev->dvi_edid = drm_get_edid(connector, &smi_connector->adapter);
+
+
+			if(sdev->dvi_edid)
 			{
 				dbg_msg("DVI get edid success.\n");
-				sdev->dvi_edid = edid_buf;
+
 				drm_connector_update_edid_property(connector, sdev->dvi_edid);
 				count = drm_add_edid_modes(connector, sdev->dvi_edid);
 			}
-			if (edid_buf == NULL || count == 0)
+			if (sdev->dvi_edid == NULL || count == 0)
 			{
 				drm_connector_update_edid_property(connector, NULL);
 				count = drm_add_modes_noedid(connector, 1920, 1080);
@@ -698,21 +709,18 @@ int smi_connector_get_modes(struct drm_connector *connector)
 		}
 		if(connector->connector_type == DRM_MODE_CONNECTOR_VGA)
 		{
-			edid_buf = drm_get_edid(connector, &smi_connector->adapter);
-
-		
-			
 		
+			sdev->vga_edid = drm_get_edid(connector, &smi_connector->adapter);
+
+			if(sdev->vga_edid){
 
-			if(edid_buf){
 			    dbg_msg("VGA get edid success.\n");
-				sdev->vga_edid = edid_buf;
 			
 				drm_connector_update_edid_property(connector, sdev->vga_edid); 
 
 				count = drm_add_edid_modes(connector, sdev->vga_edid);
 			}
-			if (edid_buf == NULL || count == 0)
+			if (sdev->vga_edid == NULL || count == 0)
 			{
 
 				drm_connector_update_edid_property(connector, NULL);
@@ -734,22 +742,22 @@ int smi_connector_get_modes(struct drm_connector *connector)
 
 				count = drm_add_modes_noedid(connector, fixed_width, fixed_height);
 				drm_set_preferred_mode(connector, fixed_width, fixed_height);
-			}else{
-			
-				edid_buf = drm_get_edid(connector, &smi_connector->adapter);
+			}
+			else
+			{
+
+			    sdev->dvi_edid = drm_get_edid(connector, &smi_connector->adapter);
 
 
-
-				if(edid_buf){
+				if(sdev->dvi_edid)
+				{
 					dbg_msg("DVI get edid success.\n");
-					sdev->dvi_edid = edid_buf;
 
 					drm_connector_update_edid_property(connector, sdev->dvi_edid); 
 
 					count = drm_add_edid_modes(connector, sdev->dvi_edid);
 				}
-		
-				if (edid_buf == NULL || count == 0)
+				if (sdev->dvi_edid == NULL || count == 0)
 				{
 
 					drm_connector_update_edid_property(connector, NULL);
@@ -762,39 +770,40 @@ int smi_connector_get_modes(struct drm_connector *connector)
 		}
 		if(connector->connector_type == DRM_MODE_CONNECTOR_VGA)
 		{
-			edid_buf = drm_get_edid(connector, &smi_connector->adapter);
 
-			if (edid_buf)
+		
+		    sdev->vga_edid = drm_get_edid(connector, &smi_connector->adapter);
+
+
+			if(sdev->vga_edid)
 			{
-				dbg_msg("VGA get edid success.\n");
-				sdev->vga_edid = edid_buf;
+			    dbg_msg("VGA get edid success.\n");
+
 				drm_connector_update_edid_property(connector, sdev->vga_edid);
 				count = drm_add_edid_modes(connector, sdev->vga_edid);
 			}
-			if (edid_buf == NULL || count == 0)
-			{
 
+			if (sdev->vga_edid == NULL || count == 0)
+			{
 				drm_connector_update_edid_property(connector, NULL);
 				count = drm_add_modes_noedid(connector, 1920, 1080);
 				drm_set_preferred_mode(connector, fixed_width, fixed_height);
 			}
-
 		}
 		if(connector->connector_type == DRM_MODE_CONNECTOR_HDMIA)
 		{
-			edid_buf = drm_get_edid(connector, &smi_connector->adapter);
 
+			sdev->hdmi_edid = drm_get_edid(connector, &smi_connector->adapter);
             //hw768_get_hdmi_edid(tmpedid);   // Too Slow..
-			if (edid_buf)
+			if (sdev->hdmi_edid)
 			{
 				dbg_msg("HDMIA get edid success.\n");
-				sdev->hdmi_edid = edid_buf;
 				drm_connector_update_edid_property(connector, sdev->hdmi_edid);		
 				count = drm_add_edid_modes(connector, sdev->hdmi_edid);
 				sdev->is_hdmi = drm_detect_hdmi_monitor(sdev->hdmi_edid);
                 dbg_msg("HDMI connector is %s\n",(sdev->is_hdmi ? "HDMI monitor" : "DVI monitor"));
 			}
-			if (edid_buf == NULL || count == 0)
+			if (sdev->hdmi_edid == NULL || count == 0)
 			{
 				drm_connector_update_edid_property(connector, NULL);
 				count = drm_add_modes_noedid(connector, 1920, 1080);
@@ -813,7 +822,7 @@ static enum drm_mode_status smi_connector_mode_valid(struct drm_connector *conne
 				 struct drm_display_mode *mode)
 {
 	struct smi_device *sdev = connector->dev->dev_private;
-	
+
 	u32 vrefresh = drm_mode_vrefresh(mode);	
 	
 	if ((vrefresh < 29) || (vrefresh > 61) || (vrefresh > 31 && vrefresh < 59)){  
@@ -831,8 +840,8 @@ static enum drm_mode_status smi_connector_mode_valid(struct drm_connector *conne
 	}
 
 	if(connector->connector_type == DRM_MODE_CONNECTOR_DVII){
-		if((mode->hdisplay > 1920) || (mode->vdisplay > 1080)|| (mode->clock > 150000))
-			return MODE_NOMODE;
+		if(mode->clock >= 200000)
+			return MODE_NOCLOCK;
 	}
 
 
@@ -865,9 +874,9 @@ static enum drm_connector_status smi_connector_detect(struct drm_connector
 {
 	struct smi_connector *smi_connector = to_smi_connector(connector);
 	struct smi_device *sdev = connector->dev->dev_private;
-		
+	int ret = 0;	
 #ifdef USE_HDMICHIP
-	int ret = 0;
+
 	void *edid_buf;
 #endif
 
@@ -875,7 +884,6 @@ static enum drm_connector_status smi_connector_detect(struct drm_connector
 	{
 		if (connector->connector_type == DRM_MODE_CONNECTOR_DVII)
 		{
-
 			if (force_connect & USE_DVI){
 					sdev->m_connector = sdev->m_connector | USE_DVI;
 					return connector_status_connected;
@@ -885,7 +893,7 @@ static enum drm_connector_status smi_connector_detect(struct drm_connector
 			}
 #ifdef USE_HDMICHIP	
 			if (ddk750_GetDDC_9022Access())
-				ret = ddk750_edidReadMonitorEx(SMI0_CTRL, edid_buf, 128, 0, 30, 31);
+				ret = ddk750_edidReadMonitorEx(CHANNEL0_CTRL, edid_buf, 128, 0, 30, 31);
 			ddk750_Release9022DDC();
 			if (ret)
 			{
@@ -898,20 +906,24 @@ static enum drm_connector_status smi_connector_detect(struct drm_connector
 				return connector_status_disconnected;
 			}
 #endif
+			if (hwi2c_en)
 
+                ret = ddk750_edidHeaderReadMonitorExHwI2C();
 
+            else
+				ret = drm_probe_ddc(&smi_connector->adapter);
 
-			if (!drm_probe_ddc(&smi_connector->adapter))
-
-			{
-				dbg_msg("detect DVI/Panel DO NOT connected.\n");
-				return connector_status_disconnected;
-			}
-			else
+			if (ret)
 			{
 				dbg_msg("detect DVI/Panel connected.\n");
 				return connector_status_connected;
 			}
+			else
+			{
+				dbg_msg("detect DVI/Panel DO NOT connected.\n");
+				return connector_status_disconnected;
+			}
+			
 		}
 		else if (connector->connector_type == DRM_MODE_CONNECTOR_VGA)
 		{
@@ -923,19 +935,6 @@ static enum drm_connector_status smi_connector_detect(struct drm_connector
 					return connector_status_disconnected;
 			}
 
-#if 0
-			if(ddk750_detectCRTMonitor(0, 0, 0) == 0)
-			{	
-				dbg_msg("detect CRT connected.\n");
-				return connector_status_connected;
-			}
-			else
-			{	
-				dbg_msg("detect CRT DO NOT connected.\n");
-				return connector_status_disconnected;
-			}
-
-#else
 			if(!drm_probe_ddc(&smi_connector->adapter))
 			{
 				dbg_msg("detect CRT DO NOT connected.\n");
@@ -946,8 +945,7 @@ static enum drm_connector_status smi_connector_detect(struct drm_connector
 				dbg_msg("detect CRT connected.\n");
 				return connector_status_connected;
 			}
-#endif	
-			
+	
 		}
 		else
 			return connector_status_unknown;
@@ -963,20 +961,25 @@ static enum drm_connector_status smi_connector_detect(struct drm_connector
 					sdev->m_connector = sdev->m_connector & (~USE_DVI);
 					return connector_status_disconnected;
 			}
+			
+			if (hwi2c_en)
+                ret = ddk768_edidHeaderReadMonitorExHwI2C(0);
+            else
+				ret = drm_probe_ddc(&smi_connector->adapter);
 
-			if (!drm_probe_ddc(&smi_connector->adapter))
-			{
-				dbg_msg("detect DVI DO NOT connected. \n");
-				sdev->m_connector = sdev->m_connector & (~USE_DVI);
-				return connector_status_disconnected; 
-			}
-			else
+			if (ret)
 			{
 				dbg_msg("detect DVI connected(GPIO30,31)\n");
 				sdev->m_connector =sdev->m_connector |USE_DVI;
 				return connector_status_connected;
 			}
-
+			else
+			{
+				dbg_msg("detect DVI DO NOT connected. \n");
+				sdev->m_connector =sdev->m_connector & (~USE_DVI);
+				return connector_status_disconnected;
+			}
+				 
 		}
 		else if (connector->connector_type == DRM_MODE_CONNECTOR_VGA)
 		{
@@ -987,27 +990,32 @@ static enum drm_connector_status smi_connector_detect(struct drm_connector
 					sdev->m_connector = sdev->m_connector & (~USE_VGA);
 					return connector_status_disconnected;
 			}
-
-			if (!drm_probe_ddc(&smi_connector->adapter))
-			{
-				dbg_msg("detect CRT DO NOT connected. \n");
-				sdev->m_connector =sdev->m_connector&(~USE_VGA);
-				return connector_status_disconnected;
-			}
+			
+			if (hwi2c_en)
+			    ret = ddk768_edidHeaderReadMonitorExHwI2C(1);
 			else
+				ret = drm_probe_ddc(&smi_connector->adapter);	
+
+			if (ret)
 			{
 				dbg_msg("detect CRT connected(GPIO 6, 7)\n");
 				sdev->m_connector = sdev->m_connector|USE_VGA;
 				return connector_status_connected;
 			}
-		
+			else
+			{
+				dbg_msg("detect CRT DO NOT connected. \n");
+				sdev->m_connector = sdev->m_connector&(~USE_VGA);
+				return connector_status_disconnected;
+			}
+
 		}
 		else if (connector->connector_type == DRM_MODE_CONNECTOR_HDMIA)
 		{
 
 			if ((sdev->m_connector == USE_DVI_VGA) || (sdev->m_connector == USE_ALL))
 			{
-				hw768_HDMI_Disable_Output();
+				HDMI_Disable_Output();
 				dbg_msg("set HDMI connector_status_disconnected because of VGA+DVI\n");
 				sdev->m_connector = sdev->m_connector&(~USE_HDMI);
 				return connector_status_disconnected;  //If VGA and DVI are both connected, disable HDMI
@@ -1164,7 +1172,7 @@ int smi_modeset_init(struct smi_device *cdev)
 		smi_bpp = 32;
 
 	if(cdev->specId == SPC_SM750)
-		smi_bpp = 16;
+		smi_bpp = 32;
 
 #ifdef PRIME
 	smi_bpp = 32;
@@ -1217,9 +1225,7 @@ int smi_modeset_init(struct smi_device *cdev)
 			DRM_ERROR("smi_%s_init failed\n", index?"VGA":"DVI");
 			return -1;
 		}
-		
 		drm_connector_attach_encoder(connector, encoder);
-
 	}
 
 	drm_mode_config_reset(cdev->dev);
@@ -1251,5 +1257,3 @@ void smi_modeset_fini(struct smi_device *cdev)
 		cdev->mode_info.mode_config_initialized = false;
 	}
 }
-
-
