@@ -398,7 +398,7 @@ static int snd_falconi2s_pcm_playback_trigger(struct snd_pcm_substream *substrea
 	switch (cmd) {
 	case SNDRV_PCM_TRIGGER_START:			
 		dbg_msg("PLAY SNDRV_PCM_TRIGGER_START\n");
-		memset_io(chip->pvReg + SRAM_OUTPUT_BASE, 0, SRAM_OUTPUT_SIZE);
+		memset32((void *)((unsigned long)chip->pvReg + SRAM_OUTPUT_BASE), 0, SRAM_OUTPUT_SIZE/4);
 		break;
 	case SNDRV_PCM_TRIGGER_STOP:
 		dbg_msg("PLAY SNDRV_PCM_TRIGGER_STOP\n");
@@ -424,7 +424,7 @@ static int snd_falconi2s_pcm_playback_trigger(struct snd_pcm_substream *substrea
 	switch (cmd) {
 	case SNDRV_PCM_TRIGGER_START:		
 		dbg_msg("CAPTURE SNDRV_PCM_TRIGGER_START\n");
-		memset_io(chip->pvReg + SRAM_INPUT_BASE, 0, SRAM_INPUT_SIZE);
+		memset32((void *)((unsigned long)chip->pvReg + SRAM_INPUT_BASE), 0, SRAM_INPUT_SIZE/4);
 		break;
 	case SNDRV_PCM_TRIGGER_STOP:
 		dbg_msg("CAPTURE SNDRV_PCM_TRIGGER_STOP\n");
@@ -516,7 +516,7 @@ static int snd_smi_play_copy_data(struct sm768chip *chip,int sramTxSection)
 	play_substream = chip->play_substream;
 
 	if(play_substream == NULL)
-		memset_io(chip->pvReg + SRAM_OUTPUT_BASE + SRAM_SECTION_SIZE * sramTxSection, 0x00, P_PERIOD_BYTE);
+		memset32((void *)((unsigned long)chip->pvReg + SRAM_OUTPUT_BASE) + SRAM_SECTION_SIZE * sramTxSection, 0x00, P_PERIOD_BYTE/4);
 	else{
 		play_runtime = play_substream->runtime;
 
@@ -540,7 +540,7 @@ static int snd_smi_capture_copy_data(struct sm768chip *chip,int sramTxSection)
 	capture_substream = chip->capture_substream;
 
 	if(capture_substream == NULL)	
-		memset_io(chip->pvReg + SRAM_INPUT_BASE + SRAM_SECTION_SIZE * sramTxSection, 0x00,  P_PERIOD_BYTE);
+		memset32((void *)((unsigned long)chip->pvReg + SRAM_INPUT_BASE + SRAM_SECTION_SIZE * sramTxSection), 0x00,  P_PERIOD_BYTE/4);
 		
 	else{
 		capture_runtime = capture_substream->runtime;
@@ -662,7 +662,7 @@ static int snd_falconi2s_create(struct snd_card *card,
 	SM768_AudioStart();
 
 	//clear SRAM
-	memset_io(chip->pvReg + SRAM_OUTPUT_BASE, 0, SRAM_TOTAL_SIZE);
+	memset32((void *)((unsigned long)chip->pvReg + SRAM_OUTPUT_BASE), 0, SRAM_TOTAL_SIZE/4);
 	
 	chip_irq_id=chip;/*Record chip_irq_id which will use in free_irq*/
 	dbg_msg("chip_irq_id=%p\n", chip_irq_id);
